@@ -111,6 +111,25 @@ pub trait PanelState {
             .map(|inv| inv.bang)
             .unwrap_or(internal_exec.bang);
         Ok(match internal_exec.internal {
+            Internal::apply_flags => {
+                info!("applying flags input_invocation: {:#?}", input_invocation);
+                let flags = input_invocation.and_then(|inv| inv.args.as_ref());
+                if let Some(flags) = flags {
+                    self.with_new_options(
+                        screen,
+                        &|o| {
+                            match o.apply_flags(flags) {
+                                Ok(()) => "*flags applied*",
+                                Err(e) => e,
+                            }
+                        },
+                        bang,
+                        con,
+                    )
+                } else {
+                    CmdResult::error(":apply_flags needs flags as arguments")
+                }
+            }
             Internal::back => CmdResult::PopState,
             Internal::copy_line | Internal::copy_path => {
                 #[cfg(not(feature = "clipboard"))]
@@ -986,6 +1005,7 @@ pub trait PanelState {
                     )
                 } else {
                     let sel_info = self.sel_info(app_state);
+                    info!("invocation: {:#?}", invocation);
                     match cc.app.con.verb_store.search_sel_info(
                         &invocation.name,
                         sel_info,
